==> tuia-advert-center-api-2.3.47-sources.jar: cn/com/duiba/tuia/core/api/dto/flowback/PlanPageQueryConditionsDTO.java <==
package cn.com.duiba.tuia.core.api.dto.flowback;

import java.util.List;

public class PlanPageQueryConditionsDTO {

    /**
     * 广告id
     */
    private Long advertId;

    /**
     * 广告名称
     */
    private String advertName;

    /**
     * 广告主 名称
     */
    private String advertiserName;

    /**
     * 过滤后的广告id集合
     */
    private List<Long> filtedAdvertIds;

    /**
     * 回流状态
     */
    private String status;

    /**
     * 开始日期
     */
    private String startDate;

    /**
     * 结束日期
     */
    private String endDate;

    /**
     * 页码
     */
    private Integer currentPage;

    /**
     * 分页查询用
     */
    private Long skipNum;

    /**
     * 分页查询用
     */
    private Long limitNum;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getAdvertiserName() {
        return advertiserName;
    }

    public void setAdvertiserName(String advertiserName) {
        this.advertiserName = advertiserName;
    }

    public List<Long> getFiltedAdvertIds() {
        return filtedAdvertIds;
    }

    public void setFiltedAdvertIds(List<Long> filtedAdvertIds) {
        this.filtedAdvertIds = filtedAdvertIds;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public Integer getCurrentPage() {
        return currentPage;
    }

    public void setCurrentPage(Integer currentPage) {
        this.currentPage = currentPage;
    }

    public Long getSkipNum() {
        return skipNum;
    }

    public void setSkipNum(Long skipNum) {
        this.skipNum = skipNum;
    }

    public Long getLimitNum() {
        return limitNum;
    }

    public void setLimitNum(Long limitNum) {
        this.limitNum = limitNum;
    }
}

==> tuia-advert-center-api-2.5.16-sources.jar: cn/com/duiba/tuia/core/api/dto/flowback/PlanPageQueryConditionsDTO.java <==
package cn.com.duiba.tuia.core.api.dto.flowback;

import java.io.Serializable;
import java.util.List;

public class PlanPageQueryConditionsDTO implements Serializable {

    private static final long serialVersionUID = -9149273420321595493L;
    /**
     * 广告id
     */
    private Long advertId;

    /**
     * 广告名称
     */
    private String advertName;

    /**
     * 广告主 名称
     */
    private String advertiserName;

    /**
     * 过滤后的广告id集合
     */
    private List<Long> filtedAdvertIds;

    /**
     * 回流状态
     */
    private String status;

    /**
     * 开始日期
     */
    private String startDate;

    /**
     * 结束日期
     */
    private String endDate;

    /**
     * 页码
     */
    private Integer currentPage;

    /**
     * 分页查询用
     */
    private Long skipNum;

    /**
     * 分页查询用
     */
    private Long limitNum;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getAdvertiserName() {
        return advertiserName;
    }

    public void setAdvertiserName(String advertiserName) {
        this.advertiserName = advertiserName;
    }

    public List<Long> getFiltedAdvertIds() {
        return filtedAdvertIds;
    }

    public void setFiltedAdvertIds(List<Long> filtedAdvertIds) {
        this.filtedAdvertIds = filtedAdvertIds;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public Integer getCurrentPage() {
        return currentPage;
    }

    public void setCurrentPage(Integer currentPage) {
        this.currentPage = currentPage;
    }

    public Long getSkipNum() {
        return skipNum;
    }

    public void setSkipNum(Long skipNum) {
        this.skipNum = skipNum;
    }

    public Long getLimitNum() {
        return limitNum;
    }

    public void setLimitNum(Long limitNum) {
        this.limitNum = limitNum;
    }
}
